@@ -3,7 +3,7 @@ testthat::test_that('no errors and successful run', {
   
   load(testthat::test_path("test_data", "pck_res.rda"))
   
-  mockery::stub(all_resources, "httr::GET", function(...) pck_res)
+  mockery::stub(all_resources, "httr::RETRY", function(...) pck_res)
   
   testthat::expect_equal(
     digest::digest(all_resources(
@@ -17,7 +17,7 @@ testthat::test_that('WARNING when arguments leads to 0 row data.frame', {
   
   load(testthat::test_path("test_data", "pck_res.rda"))
   
-  mockery::stub(all_resources, "httr::GET", function(...) pck_res)
+  mockery::stub(all_resources, "httr::RETRY", function(...) pck_res)
   
   testthat::expect_warning(
     all_resources(
@@ -36,3 +36,4 @@ testthat::test_that('live query returns no errors and successful run', {
       resource_contains = "European"
     )))
 })
+
